@@ -1,11 +1,16 @@
 package data
 
 import (
+	"context"
+
+	"github.com/hairyhenderson/gomplate/v3/internal/deprecated"
 	"github.com/hairyhenderson/gomplate/v3/libkv"
 	"github.com/pkg/errors"
 )
 
-func readBoltDB(source *Source, args ...string) (data []byte, err error) {
+// Deprecated: don't use
+func readBoltDB(ctx context.Context, source *Source, args ...string) (data []byte, err error) {
+	deprecated.WarnDeprecated(ctx, "boltdb support is deprecated and will be removed in a future major version of gomplate")
 	if source.kv == nil {
 		source.kv, err = libkv.NewBoltDB(source.URL)
 		if err != nil {
